==> mx-packageinstaller-pkglist_19.08.01.tar.xz: mx-packageinstaller-pkglist/inkscape.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
Inkscape
</name>

<description>
   <am>a vector-based drawing program</am>
   <ar>a vector-based drawing program</ar>
   <bg>a vector-based drawing program</bg>
   <ca>Programa de dibuix basat en vectors</ca>
   <cs>a vector-based drawing program</cs>
   <da>et vektorbaseret tegneprogram</da>
   <de>Ein vektorbasiertes Zeichenprogramm</de>
   <el>ένα πρόγραμμα σχεδίασης vector-based</el>
   <en>a vector-based drawing program</en>
   <es>programa de dibujo vectorial</es>
   <et>a vector-based drawing program</et>
   <eu>a vector-based drawing program</eu>
   <fa>a vector-based drawing program</fa>
   <fi>Vektoripohjainen piirto-ohjelma</fi>
   <fr>Programme de dessin vectoriel</fr>
   <he_IL>a vector-based drawing program</he_IL>
   <hi>a vector-based drawing program</hi>
   <hr>a vector-based drawing program</hr>
   <hu>a vector-based drawing program</hu>
   <id>a vector-based drawing program</id>
   <is>a vector-based drawing program</is>
   <it>programma di disegno vettoriale</it>
   <ja_JP>a vector-based drawing program</ja_JP>
   <ja>a vector-based drawing program</ja>
   <kk>a vector-based drawing program</kk>
   <ko>a vector-based drawing program</ko>
   <lt>a vector-based drawing program</lt>
   <mk>a vector-based drawing program</mk>
   <nb>a vector-based drawing program</nb>
   <nl>een vector-gebaseerd tekenprogramma</nl>
   <pl>program do tworzenia grafiki wektorowej</pl>
   <pt_BR>a vector-based drawing program</pt_BR>
   <pt>Programa de desenho de base vectorial</pt>
   <ro>a vector-based drawing program</ro>
   <ru>Векторный графический редактор с богатым функционалом</ru>
   <sk>a vector-based drawing program</sk>
   <sl>a vector-based drawing program</sl>
   <sq>a vector-based drawing program</sq>
   <sr>a vector-based drawing program</sr>
   <sv>ett vektorbaserat ritprogram</sv>
   <tr>a vector-based drawing program</tr>
   <uk>програма для роботи з векторною графікою</uk>
   <zh_CN>a vector-based drawing program</zh_CN>
   <zh_TW>a vector-based drawing program</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/295/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
inkscape
aspell
imagemagick
libwmf-bin
perlmagick
pstoedit
python-lxml
python-numpy
transfig
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
inkscape
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.01.tar.xz: mx-packageinstaller-pkglist/inkscape.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
Inkscape
</name>

<description>
   <am>a vector-based drawing program</am>
   <ar>a vector-based drawing program</ar>
   <bg>a vector-based drawing program</bg>
   <ca>Programa de dibuix basat en vectors</ca>
   <cs>a vector-based drawing program</cs>
   <da>et vektorbaseret tegneprogram</da>
   <de>Ein vektorbasiertes Zeichenprogramm</de>
   <el>ένα πρόγραμμα σχεδίασης vector-based</el>
   <en>a vector-based drawing program</en>
   <es>programa de dibujo vectorial</es>
   <et>a vector-based drawing program</et>
   <eu>a vector-based drawing program</eu>
   <fa>a vector-based drawing program</fa>
   <fi>Vektoripohjainen piirto-ohjelma</fi>
   <fr>Programme de dessin vectoriel</fr>
   <he_IL>a vector-based drawing program</he_IL>
   <hi>a vector-based drawing program</hi>
   <hr>a vector-based drawing program</hr>
   <hu>a vector-based drawing program</hu>
   <id>a vector-based drawing program</id>
   <is>a vector-based drawing program</is>
   <it>programma di disegno vettoriale</it>
   <ja_JP>a vector-based drawing program</ja_JP>
   <ja>a vector-based drawing program</ja>
   <kk>a vector-based drawing program</kk>
   <ko>a vector-based drawing program</ko>
   <lt>a vector-based drawing program</lt>
   <mk>a vector-based drawing program</mk>
   <nb>a vector-based drawing program</nb>
   <nl>een vector-gebaseerd tekenprogramma</nl>
   <pl>program do tworzenia grafiki wektorowej</pl>
   <pt_BR>Programa de desenho de base vectorial</pt_BR>
   <pt>Programa de desenho de base vectorial</pt>
   <ro>a vector-based drawing program</ro>
   <ru>Векторный графический редактор с богатым функционалом</ru>
   <sk>a vector-based drawing program</sk>
   <sl>a vector-based drawing program</sl>
   <sq>a vector-based drawing program</sq>
   <sr>a vector-based drawing program</sr>
   <sv>ett vektorbaserat ritprogram</sv>
   <tr>bir vektörel çizim programı</tr>
   <uk>програма для роботи з векторною графікою</uk>
   <zh_CN>a vector-based drawing program</zh_CN>
   <zh_TW>a vector-based drawing program</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/295/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
inkscape
aspell
imagemagick
libwmf-bin
perlmagick
pstoedit
python-lxml
python-numpy
transfig
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
inkscape
</uninstall_package_names>
</app>
